@@ -22,9 +22,9 @@ class QtFrameBuffer : public FrameBuffer
 {
     Q_OBJECT
 public:
-    explicit QtFrameBuffer(WId id, QObject *parent = 0);
+    explicit QtFrameBuffer(WId id, QObject *parent = nullptr);
 
-    ~QtFrameBuffer();
+    ~QtFrameBuffer() override;
 
     int depth() override;
     int height() override;
