@@ -21,7 +21,7 @@
 #include "connectiondialog.h"
 #include "krfbconfig.h"
 #include "sockethelpers.h"
-#include "events.h"
+#include "eventsmanager.h"
 #include <QSocketNotifier>
 #include <QDebug>
 #include <poll.h>
@@ -37,6 +37,7 @@ struct RfbClient::Private
     bool controlEnabled;
     rfbClientPtr client;
     QSocketNotifier *notifier;
+    QSharedPointer<EventHandler> eventHandler;
     QString remoteAddressString;
 };
 
@@ -49,6 +50,8 @@ RfbClient::RfbClient(rfbClientPtr client, QObject* parent)
     d->notifier = new QSocketNotifier(client->sock, QSocketNotifier::Read, this);
     d->notifier->setEnabled(false);
     connect(d->notifier, &QSocketNotifier::activated, this, &RfbClient::onSocketActivated);
+
+    d->eventHandler = EventsManager::instance()->eventHandler();
 }
 
 RfbClient::~RfbClient()
@@ -110,14 +113,14 @@ rfbClientPtr RfbClient::getRfbClientPtr()
 void RfbClient::handleKeyboardEvent(bool down, rfbKeySym keySym)
 {
     if (d->controlEnabled) {
-        EventHandler::handleKeyboard(down, keySym);
+        d->eventHandler->handleKeyboard(down, keySym);
     }
 }
 
 void RfbClient::handleMouseEvent(int buttonMask, int x, int y)
 {
     if (d->controlEnabled) {
-        EventHandler::handlePointer(buttonMask, x, y);
+        d->eventHandler->handlePointer(buttonMask, x, y);
     }
 }
 
@@ -218,7 +221,7 @@ bool PendingRfbClient::vncAuthCheckPassword(const QByteArray& password, const QB
     unsigned char challenge[CHALLENGESIZE];
 
     memcpy(challenge, m_rfbClient->authChallenge, CHALLENGESIZE);
-    bzero(passwd, MAXPWLEN);
+    memset(passwd, 0, MAXPWLEN);
 
     if (!password.isEmpty()) {
         strncpy(passwd, password.constData(),
